@@ -1,11 +1,9 @@
 package Opsview::REST;
 {
-  $Opsview::REST::VERSION = '0.006';
+  $Opsview::REST::VERSION = '0.007';
 }
 
 use Moo;
-use namespace::autoclean;
-
 use Carp;
 use Opsview::REST::Config;
 use Opsview::REST::Exception;
@@ -54,7 +52,7 @@ has [qw/ pass auth_tkt /] => (
             require JSON::XS;
             my $uri = Opsview::REST::Config->new(
                 $obj_type,
-                json_filter => JSON::XS::encode_json {@_},
+                json_filter => JSON::XS::encode_json({@_}),
             );
             return $self->get($uri->as_string);
 
@@ -64,10 +62,21 @@ has [qw/ pass auth_tkt /] => (
         # URL: /rest/config/{object_type}
         # POST - add a new object or a list of object type
         *{__PACKAGE__ . "::create_$obj_type"} = sub {
-            my $uri = Opsview::REST::Config->new($obj_type);
-            return shift->post($uri->as_string, { @_ });
+            my $self = shift;
+            my $uri  = Opsview::REST::Config->new($obj_type);
+            my $to_post;
+            if (ref $_[0] && ref $_[0] eq 'ARRAY') {
+                $to_post = { list => shift };
+            } else {
+                $to_post = { @_ };
+            }
+            return $self->post($uri->as_string, $to_post);
         };
 
+        # Alias to call last method in plural
+        *{__PACKAGE__ . "::create_${obj_type}s"} =
+            *{__PACKAGE__ . "::create_$obj_type"};
+
         # Clone object
         # URL: /rest/config/{object_type}/{id}
         # POST - clone this object with merged incoming data to create
@@ -86,9 +95,20 @@ has [qw/ pass auth_tkt /] => (
         # PUT - create or update (based on unique keys) object or a list
         # of objects
         *{__PACKAGE__ . "::create_or_update_$obj_type"} = sub {
-            my $uri = Opsview::REST::Config->new($obj_type);
-            return shift->put($uri->as_string, { @_ });
+            my $self = shift;
+            my $uri  = Opsview::REST::Config->new($obj_type);
+            my $to_post;
+            if (ref $_[0] && ref $_[0] eq 'ARRAY') {
+                $to_post = { list => shift };
+            } else {
+                $to_post = { @_ };
+            }
+            return $self->put($uri->as_string, $to_post);
         };
+        # Alias to call last method in plural
+        *{__PACKAGE__ . "::create_or_update_${obj_type}s"} =
+            *{__PACKAGE__ . "::create_or_update_$obj_type"};
+
 
         # Update
         # URL: /rest/config/{object_type}/{id}
@@ -239,13 +259,11 @@ Opsview::REST - Interface to the Opsview REST API
         pass     => 'password',
     );
 
-    # These are equivalent
-    my $status = $ops->get('/status/hostgroup?hostgroupid=1&...');
+    # Check status
     my $status = $ops->status(
         'hostgroup',
         'hostgroupid' => [1, 2],
         'filter'      => 'unhandled',
-        ...
     );
 
     # Configuration methods
@@ -262,7 +280,25 @@ Opsview::REST - Interface to the Opsview REST API
         ip   => '192.168.0.2',
     );
 
-    # Reload it after config
+    # Search methods support complex SQL::Abstract queries
+    my $hosts = $ops->get_hosts(
+        -or => [
+            name => { -like => '%.example.com' },
+            ip   => { -like => '10.25.%' },
+        ],
+    );
+
+    # Update several objects at once
+    map { $_->{check_attempts} = 4 } @{ $hosts->{list} };
+    my $response = $ops->create_or_update_hosts($hosts->{list});
+
+    # ... or only one
+    my $response = $ops->create_or_update_host(
+        name         => 'host1.example.com',
+        snmp_version => '2c',
+    );
+
+    # Reload after make changes in config
     $ops->reload;
 
 =head1 DESCRIPTION
@@ -357,7 +393,8 @@ More info: L<http://docs.opsview.com/doku.php?id=opsview-community:restapi:ackno
 
 =head2 acknowledge_list
 
-Lists the problems which the current logged in user has permission to acknowledge.
+Lists the problems which the current logged in user has permission to
+acknowledge.
 
 =head2 reload
 
@@ -373,29 +410,78 @@ Get status of reload.
 
 More info: L<http://docs.opsview.com/doku.php?id=opsview-community:restapi#initiating_an_opsview_reload>
 
-=head2 get_*
+=head2 Config methods for single objects
 
-=head2 create_*
+=head3 get_*
 
-=head2 clone_*
+=head3 create_*
 
-=head2 update_*
+=head3 clone_*
 
-=head2 delete_*
+=head3 create_or_update_*
+
+=head3 delete_*
 
 This methods will be generated for the following types of objects: C<contact>,
 C<role>, C<servicecheck>, C<hosttemplate>, C<attribute>, C<timeperiod>,
 C<hostgroup>, C<servicegroup>, C<notificationmethod>, C<hostcheckcommand>,
 C<keyword>, C<monitoringserver>.
 
-They all, except C<create>, require the object's id. Additionally, C<create>,
-C<clone> and C<update> accept a list of key-value pairs.
+They all except C<create>, require the object's id. Additionally, C<create>,
+C<clone> and C<create_or_update> accept a list of key-value pairs:
 
-More info: L<http://docs.opsview.com/doku.php?id=opsview3.14:restapi:config>
+    my $host1 = $ops->create_host(
+        name => 'host1',
+        ip   => '192.168.10.27',
+    );
 
-=head1 TODO
+    $ops->clone_host(
+        $host1->{object}->{id},
+        name => 'host2',
+        ip   => '192.168.10.28',
+    );
 
-Document and test configuration methods to handle sets of objects.
+    $host->delete($id);
+
+=head2 Config methods for multiple objects
+
+=head3 get_*
+
+=head3 create_*
+
+=head3 create_or_update_*
+
+This methods will be generated for the following types of objects: C<contacts>,
+C<roles>, C<servicechecks>, C<hosttemplates>, C<attributes>, C<timeperiods>,
+C<hostgroups>, C<servicegroups>, C<notificationmethods>, C<hostcheckcommands>,
+C<keywords>, C<monitoringservers>.
+
+C<get> accepts complex queries in L<SQL::Abstract> format.
+
+C<create_or_update> is specially useful when you want to update several objects
+with a single call:
+
+    # First get a list of objects you want to modify
+    my $dbhosts = $ops->get_hosts(
+        name    => { -like => 'db%' },
+    );
+
+    # $dbhosts = {
+    #   summary => { ... },
+    #   list => [ { name => 'db1.example.com , ... }, ... ],
+    # };
+
+    # Modify them as you need
+    map { $_->{check_attempts} = 4 } @{ $dbhosts->{list} };
+
+    # Make the call
+    $ops->create_or_update($dbhosts->{list});
+
+
+To know which fields are accepted for each type of object, the format of the
+responses, and additional info:
+
+L<http://docs.opsview.com/doku.php?id=opsview-community:restapi:config>
 
 =head1 SEE ALSO
 
@@ -405,6 +491,8 @@ Document and test configuration methods to handle sets of objects.
 
 L<http://www.opsview.org/>
 
+L<http://docs.opsview.com/doku.php?id=opsview-community:restapi>
+
 =item *
 
 L<Opsview REST API Documentation|http://docs.opsview.com/doku.php?id=opsview-community:restapi>
