@@ -5,7 +5,9 @@ use warnings;
 
 require Exporter;
 our @ISA = qw/Exporter/;
-our @EXPORT = qw/get_opsview get_opsview_authtkt test_urls/;
+our @EXPORT = qw/
+    get_opsview get_opsview_authtkt test_urls get_random_name get_random_ip
+/;
 
 use Opsview::REST;
 
@@ -31,11 +33,11 @@ sub get_opsview_authtkt {
     my $ticket = $ENV{OPSVIEW_REST_AUTHTKT};
     unless (defined $ticket) {
         $ticket = Apache::AuthTkt->new(
-            secret      => $secret,
+            secret      => $ENV{OPSVIEW_REST_AUTHTKT_SECRET} || $secret,
             digest_type => 'MD5',
         )->ticket(
             uid     => $user,
-            ip_addr => '127.0.0.1',
+            ip_addr => $ENV{OPSVIEW_REST_AUTHTKT_IP} || '127.0.0.1',
         );
     }
 
@@ -58,5 +60,14 @@ sub test_urls {
     };
 }
 
+sub get_random_name {
+    require String::Random;
+    my $sr = String::Random->new;
+    return $sr->randregex('\w{8}');
+}
+
+sub get_random_ip {
+    return join(".", map { int(rand(255)) } (1..4));
+}
 1;
 
